@@ -125,15 +125,15 @@ class gram():
         return gram(f"{self.value}{case_content}")
 
 
-def quant(gr, values):
+def quant(gr, **kwargs):
     quant_conds = []
-    for key in values:
+    for key in kwargs:
         val_str = ""
-        val = values[key]
+        val = kwargs[key]
         if isinstance(val, list):
-            val_str = "&".join(val)
+            val_str = "&".join(map(lambda x: x.rule(), val))
         else:
-            val_str = str(val)
+            val_str = val.rule()
         quant_conds.append(f"{key}={val_str}")
     return "QUANT[" + ",".join(quant_conds) + "] " + gr.rule()
 
